==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cognito/kotlin/inputs/UserPoolClientAnalyticsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cognito.kotlin.inputs

import com.pulumi.aws.cognito.inputs.UserPoolClientAnalyticsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property applicationArn Application ARN for an Amazon Pinpoint application. Conflicts with `external_id` and `role_arn`.
 * @property applicationId Application ID for an Amazon Pinpoint application.
 * @property externalId ID for the Analytics Configuration. Conflicts with `application_arn`.
 * @property roleArn ARN of an IAM role that authorizes Amazon Cognito to publish events to Amazon Pinpoint analytics. Conflicts with `application_arn`.
 * @property userDataShared If set to `true`, Amazon Cognito will include user data in the events it publishes to Amazon Pinpoint analytics.
 */
public data class UserPoolClientAnalyticsConfigurationArgs(
    public val applicationArn: Output<String>? = null,
    public val applicationId: Output<String>? = null,
    public val externalId: Output<String>? = null,
    public val roleArn: Output<String>? = null,
    public val userDataShared: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.aws.cognito.inputs.UserPoolClientAnalyticsConfigurationArgs> {
    override fun toJava(): com.pulumi.aws.cognito.inputs.UserPoolClientAnalyticsConfigurationArgs =
        com.pulumi.aws.cognito.inputs.UserPoolClientAnalyticsConfigurationArgs.builder()
            .applicationArn(applicationArn?.applyValue({ args0 -> args0 }))
            .applicationId(applicationId?.applyValue({ args0 -> args0 }))
            .externalId(externalId?.applyValue({ args0 -> args0 }))
            .roleArn(roleArn?.applyValue({ args0 -> args0 }))
            .userDataShared(userDataShared?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserPoolClientAnalyticsConfigurationArgs].
 */
@PulumiTagMarker
public class UserPoolClientAnalyticsConfigurationArgsBuilder internal constructor() {
    private var applicationArn: Output<String>? = null

    private var applicationId: Output<String>? = null

    private var externalId: Output<String>? = null

    private var roleArn: Output<String>? = null

    private var userDataShared: Output<Boolean>? = null

    /**
     * @param value Application ARN for an Amazon Pinpoint application. Conflicts with `external_id` and `role_arn`.
     */
    @JvmName("gglluhaftlubltqw")
    public suspend fun applicationArn(`value`: Output<String>) {
        this.applicationArn = value
    }

    /**
     * @param value Application ID for an Amazon Pinpoint application.
     */
    @JvmName("papxmuwtouaeuaam")
    public suspend fun applicationId(`value`: Output<String>) {
        this.applicationId = value
    }

    /**
     * @param value ID for the Analytics Configuration. Conflicts with `application_arn`.
     */
    @JvmName("bcmkjybpkuocwfrs")
    public suspend fun externalId(`value`: Output<String>) {
        this.externalId = value
    }

    /**
     * @param value ARN of an IAM role that authorizes Amazon Cognito to publish events to Amazon Pinpoint analytics. Conflicts with `application_arn`.
     */
    @JvmName("viqxsweqjvtivjfm")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value If set to `true`, Amazon Cognito will include user data in the events it publishes to Amazon Pinpoint analytics.
     */
    @JvmName("uuqqvigkcxuisbct")
    public suspend fun userDataShared(`value`: Output<Boolean>) {
        this.userDataShared = value
    }

    /**
     * @param value Application ARN for an Amazon Pinpoint application. Conflicts with `external_id` and `role_arn`.
     */
    @JvmName("kdvogcocebwtkchk")
    public suspend fun applicationArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.applicationArn = mapped
    }

    /**
     * @param value Application ID for an Amazon Pinpoint application.
     */
    @JvmName("wdwcfbsejopmyivm")
    public suspend fun applicationId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.applicationId = mapped
    }

    /**
     * @param value ID for the Analytics Configuration. Conflicts with `application_arn`.
     */
    @JvmName("keqbsnpuoolytrtx")
    public suspend fun externalId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.externalId = mapped
    }

    /**
     * @param value ARN of an IAM role that authorizes Amazon Cognito to publish events to Amazon Pinpoint analytics. Conflicts with `application_arn`.
     */
    @JvmName("gvboimabhmssfslw")
    public suspend fun roleArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    /**
     * @param value If set to `true`, Amazon Cognito will include user data in the events it publishes to Amazon Pinpoint analytics.
     */
    @JvmName("fhukdejdsstgmxno")
    public suspend fun userDataShared(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userDataShared = mapped
    }

    internal fun build(): UserPoolClientAnalyticsConfigurationArgs =
        UserPoolClientAnalyticsConfigurationArgs(
            applicationArn = applicationArn,
            applicationId = applicationId,
            externalId = externalId,
            roleArn = roleArn,
            userDataShared = userDataShared,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cognito/kotlin/inputs/UserPoolClientAnalyticsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cognito.kotlin.inputs

import com.pulumi.aws.cognito.inputs.UserPoolClientAnalyticsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property applicationArn Application ARN for an Amazon Pinpoint application. Conflicts with `external_id` and `role_arn`.
 * @property applicationId Application ID for an Amazon Pinpoint application.
 * @property externalId ID for the Analytics Configuration. Conflicts with `application_arn`.
 * @property roleArn ARN of an IAM role that authorizes Amazon Cognito to publish events to Amazon Pinpoint analytics. Conflicts with `application_arn`.
 * @property userDataShared If set to `true`, Amazon Cognito will include user data in the events it publishes to Amazon Pinpoint analytics.
 */
public data class UserPoolClientAnalyticsConfigurationArgs(
    public val applicationArn: Output<String>? = null,
    public val applicationId: Output<String>? = null,
    public val externalId: Output<String>? = null,
    public val roleArn: Output<String>? = null,
    public val userDataShared: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.aws.cognito.inputs.UserPoolClientAnalyticsConfigurationArgs> {
    override fun toJava(): com.pulumi.aws.cognito.inputs.UserPoolClientAnalyticsConfigurationArgs =
        com.pulumi.aws.cognito.inputs.UserPoolClientAnalyticsConfigurationArgs.builder()
            .applicationArn(applicationArn?.applyValue({ args0 -> args0 }))
            .applicationId(applicationId?.applyValue({ args0 -> args0 }))
            .externalId(externalId?.applyValue({ args0 -> args0 }))
            .roleArn(roleArn?.applyValue({ args0 -> args0 }))
            .userDataShared(userDataShared?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserPoolClientAnalyticsConfigurationArgs].
 */
@PulumiTagMarker
public class UserPoolClientAnalyticsConfigurationArgsBuilder internal constructor() {
    private var applicationArn: Output<String>? = null

    private var applicationId: Output<String>? = null

    private var externalId: Output<String>? = null

    private var roleArn: Output<String>? = null

    private var userDataShared: Output<Boolean>? = null

    /**
     * @param value Application ARN for an Amazon Pinpoint application. Conflicts with `external_id` and `role_arn`.
     */
    @JvmName("qgmktbcghawleyhk")
    public suspend fun applicationArn(`value`: Output<String>) {
        this.applicationArn = value
    }

    /**
     * @param value Application ID for an Amazon Pinpoint application.
     */
    @JvmName("urembgnjctvmrecb")
    public suspend fun applicationId(`value`: Output<String>) {
        this.applicationId = value
    }

    /**
     * @param value ID for the Analytics Configuration. Conflicts with `application_arn`.
     */
    @JvmName("uhhfsuhxtlhnlgrm")
    public suspend fun externalId(`value`: Output<String>) {
        this.externalId = value
    }

    /**
     * @param value ARN of an IAM role that authorizes Amazon Cognito to publish events to Amazon Pinpoint analytics. Conflicts with `application_arn`.
     */
    @JvmName("cctjklbwnjafgntj")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value If set to `true`, Amazon Cognito will include user data in the events it publishes to Amazon Pinpoint analytics.
     */
    @JvmName("gfilmajgavtohqnl")
    public suspend fun userDataShared(`value`: Output<Boolean>) {
        this.userDataShared = value
    }

    /**
     * @param value Application ARN for an Amazon Pinpoint application. Conflicts with `external_id` and `role_arn`.
     */
    @JvmName("jjlrirmmlvhbhdea")
    public suspend fun applicationArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.applicationArn = mapped
    }

    /**
     * @param value Application ID for an Amazon Pinpoint application.
     */
    @JvmName("tteaexbjjmkedjbo")
    public suspend fun applicationId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.applicationId = mapped
    }

    /**
     * @param value ID for the Analytics Configuration. Conflicts with `application_arn`.
     */
    @JvmName("nayhmidhwlqhdrwr")
    public suspend fun externalId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.externalId = mapped
    }

    /**
     * @param value ARN of an IAM role that authorizes Amazon Cognito to publish events to Amazon Pinpoint analytics. Conflicts with `application_arn`.
     */
    @JvmName("ekojsfsaclabvrhb")
    public suspend fun roleArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    /**
     * @param value If set to `true`, Amazon Cognito will include user data in the events it publishes to Amazon Pinpoint analytics.
     */
    @JvmName("rdimeuhxqrljwfhi")
    public suspend fun userDataShared(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userDataShared = mapped
    }

    internal fun build(): UserPoolClientAnalyticsConfigurationArgs =
        UserPoolClientAnalyticsConfigurationArgs(
            applicationArn = applicationArn,
            applicationId = applicationId,
            externalId = externalId,
            roleArn = roleArn,
            userDataShared = userDataShared,
        )
}
